
//   Copyright 2021 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.
//

import QtQuick 2.6
import QtQuick.Controls 2.2
import Esri.ArcGISRuntime 100.15

ApplicationWindow {
    id: appWindow
    width: 800
    height: 600
    title: "Display_a_map"

    // add a mapView component
    MapView {
        anchors.fill: parent
        // set focus to enable keyboard navigation
        focus: true

        // add a map to the mapview

        Map {
            // add the ArcGISStreets basemap to the map
            initBasemapStyle: Enums.BasemapStyleArcGISTopographic
            initialViewpoint: viewPoint
        }

        GraphicsOverlay {
            id: graphicsOverlay
        }

        ViewpointCenter {
            id: viewPoint
            center: Point {
                x: -118.80543
                y: 34.02700
                spatialReference: SpatialReference {wkid: 4326}
            }
    // Specify the scale
        targetScale: 100000.0
        }
    }

    Point {
        id: dume_beach
        x: -118.80657463861
        y: 34.0005930608889
        spatialReference: SpatialReference {wkid: 4326}
    }

    SimpleMarkerSymbol {
        id: point_symbol
        style: Enums.SimpleMarkerSymbolStyleCircle
        color: "red"
        size: 10
        outline: line_symbol
    }

    SimpleLineSymbol {
        id: line_symbol
        style: Enums.SimpleLineSymbolStyleSolid
        color: "blue"
        width: 3
        antiAlias: true
    }

    PolygonBuilder {
        id: polygon_builder
        spatialReference: SpatialReference {wkid: 4326}
    }

    SimpleFillSymbol {
        id: polygon_fill_symbol
        style: Enums.SimpleFillSymbolStyleSolid
        color: "yellow"

        SimpleLineSymbol {
            style: Enums.SimpleLineSymbolStyleSolid
            color: "blue"
            width: 3
            antiAlias: true
        }
    }

    Component.onCompleted: {
        // add a point
        const point_graphic = createGraphic(dume_beach, point_symbol);
        graphicsOverlay.graphics.append(point_graphic);

        // add line
        const line = createLine();
        const line_graphic = createGraphic(line, line_symbol);
        graphicsOverlay.graphics.append(line_graphic);

        // add polygon
        const polygon = createPolygon();
        const polygon_graphic = createGraphic(polygon, polygon_fill_symbol);
        graphicsOverlay.graphics.append(polygon_graphic);

    }

    function createGraphic(geometry, symbol) {
        const graphic = ArcGISRuntimeEnvironment.createObject("Graphic");
        graphic.geometry = geometry;
        graphic.symbol = symbol;
        return graphic;
    }

    function createLine() {
        // create polyline using json
        const line1 = {"paths":[[[-118.8215, 34.0140],
                                 [-118.8149, 34.0081],
                                 [-118.8089, 34.0017]]],
                                 "spatialReference":{"wkid":4326}};
        return ArcGISRuntimeEnvironment.createObject("Polyline", {"json": line1});
    }

    function createPolygon() {
        // create the polygon using the builder class
        polygon_builder.addPointXY(-118.8190, 34.0138);
        polygon_builder.addPointXY(-118.8068, 34.0216);
        polygon_builder.addPointXY(-118.7914, 34.0164);
        polygon_builder.addPointXY(-118.7960, 34.0086);
        polygon_builder.addPointXY(-118.8086, 34.0035);
        return polygon_builder.geometry;
    }

}

